Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4831)

Unified Diff: chrome/browser/chrome_content_browser_client.cc

Issue 10916348: Switch SSLTabHelper to use WebContentsUserData. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/ssl/ssl_add_cert_handler.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/chrome_content_browser_client.cc
diff --git a/chrome/browser/chrome_content_browser_client.cc b/chrome/browser/chrome_content_browser_client.cc
index 15cc0afab0f0ad8fe39f3cc7026bd820c52cd4d7..e900ebf68e7a882daf8fab5e6bad745e6ac5853d 100644
--- a/chrome/browser/chrome_content_browser_client.cc
+++ b/chrome/browser/chrome_content_browser_client.cc
@@ -63,7 +63,7 @@
#include "chrome/browser/spellchecker/spellcheck_message_filter.h"
#include "chrome/browser/ssl/ssl_add_cert_handler.h"
#include "chrome/browser/ssl/ssl_blocking_page.h"
-#include "chrome/browser/tab_contents/tab_contents_ssl_helper.h"
+#include "chrome/browser/ssl/ssl_tab_helper.h"
#include "chrome/browser/tab_contents/tab_util.h"
#include "chrome/browser/toolkit_extra_parts.h"
#include "chrome/browser/ui/tab_contents/chrome_web_contents_view_delegate.h"
@@ -1177,15 +1177,15 @@ void ChromeContentBrowserClient::SelectClientCertificate(
}
}
- TabContents* tab_contents = TabContents::FromWebContents(tab);
- if (!tab_contents) {
- // If there is no TabContents for the given WebContents then we can't
+ SSLTabHelper* ssl_tab_helper = SSLTabHelper::FromWebContents(tab);
+ if (!ssl_tab_helper) {
+ // If there is no SSLTabHelper for the given WebContents then we can't
// show the user a dialog to select a client certificate. So we simply
// proceed with no client certificate.
callback.Run(NULL);
return;
}
- tab_contents->ssl_helper()->ShowClientCertificateRequestDialog(
+ ssl_tab_helper->ShowClientCertificateRequestDialog(
network_session, cert_request_info, callback);
}
« no previous file with comments | « no previous file | chrome/browser/ssl/ssl_add_cert_handler.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698